==> pointpos_api-0.0.1.tar.gz: docs/OutletApi.md <==
# swagger.api.OutletApi

## Load the API package
```dart
import 'package:swagger/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createOutlet**](OutletApi.md#createOutlet) | **POST** /outlet | Create Outlet
[**deleteOutletByID**](OutletApi.md#deleteOutletByID) | **DELETE** /outlet/{id} | Delete Outlet By ID
[**findOutlet**](OutletApi.md#findOutlet) | **GET** /outlet | Get Outlet List
[**getOutletByID**](OutletApi.md#getOutletByID) | **GET** /outlet/{id} | Get Outlet By ID
[**updateOutletByID**](OutletApi.md#updateOutletByID) | **PUT** /outlet/{id} | Update Outlet By ID


# **createOutlet**
> Outlet createOutlet(authorization, xAPIKey, body)

Create Outlet

Create Outlet

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new Outlet(); // Outlet | 

try { 
    var result = api_instance.createOutlet(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->createOutlet: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**Outlet**](Outlet.md)|  | 

### Return type

[**Outlet**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteOutletByID**
> deleteOutletByID(authorization, xAPIKey, id)

Delete Outlet By ID

Delete Outlet By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = id_example; // String | 

try { 
    api_instance.deleteOutletByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling OutletApi->deleteOutletByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **String**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findOutlet**
> List<Outlet> findOutlet(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Outlet List

Get Outlet  List

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"receiptSettings\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findOutlet(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->findOutlet: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;receiptSettings\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<Outlet>**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getOutletByID**
> Outlet getOutletByID(authorization, xAPIKey, id)

Get Outlet By ID

Get Outlet By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = id_example; // String | 

try { 
    var result = api_instance.getOutletByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->getOutletByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **String**|  | 

### Return type

[**Outlet**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateOutletByID**
> Outlet updateOutletByID(authorization, xAPIKey, id, body)

Update Outlet By ID

Update [object Object] By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = id_example; // String | 
var body = new Outlet(); // Outlet | 

try { 
    var result = api_instance.updateOutletByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->updateOutletByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **String**|  | 
 **body** | [**Outlet**](Outlet.md)|  | 

### Return type

[**Outlet**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.2.tar.gz: docs/OutletApi.md <==
# swagger.api.OutletApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createOutlet**](OutletApi.md#createOutlet) | **POST** /outlet | Create Outlet
[**deleteOutletByID**](OutletApi.md#deleteOutletByID) | **DELETE** /outlet/{id} | Delete Outlet By ID
[**findOutlet**](OutletApi.md#findOutlet) | **GET** /outlet | Get Outlet List
[**getOutletByID**](OutletApi.md#getOutletByID) | **GET** /outlet/{id} | Get Outlet By ID
[**updateOutletByID**](OutletApi.md#updateOutletByID) | **PUT** /outlet/{id} | Update Outlet By ID


# **createOutlet**
> Outlet createOutlet(authorization, xAPIKey, body)

Create Outlet

Create Outlet

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new Outlet(); // Outlet | 

try { 
    var result = api_instance.createOutlet(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->createOutlet: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**Outlet**](Outlet.md)|  | 

### Return type

[**Outlet**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteOutletByID**
> deleteOutletByID(authorization, xAPIKey, id)

Delete Outlet By ID

Delete Outlet By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = id_example; // String | 

try { 
    api_instance.deleteOutletByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling OutletApi->deleteOutletByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **String**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findOutlet**
> List<Outlet> findOutlet(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Outlet List

Get Outlet  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"   - \"receiptSettings\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findOutlet(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->findOutlet: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;   - \&quot;receiptSettings\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<Outlet>**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getOutletByID**
> Outlet getOutletByID(authorization, xAPIKey, id)

Get Outlet By ID

Get Outlet By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = id_example; // String | 

try { 
    var result = api_instance.getOutletByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->getOutletByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **String**|  | 

### Return type

[**Outlet**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateOutletByID**
> Outlet updateOutletByID(authorization, xAPIKey, id, body)

Update Outlet By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new OutletApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = id_example; // String | 
var body = new Outlet(); // Outlet | 

try { 
    var result = api_instance.updateOutletByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling OutletApi->updateOutletByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **String**|  | 
 **body** | [**Outlet**](Outlet.md)|  | 

### Return type

[**Outlet**](Outlet.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
